@@ -33,7 +33,7 @@ class Parameter:
 class ParameterMixin(BaseModel):
     """Adding parameter functions."""
 
-    def __init__(self, parameters: dict = None) -> None:
+    def __init__(self, parameters: dict[str, float] | None = None) -> None:
         self.parameters: Dict[str, float] = {}
         self.derived_parameters: Dict[str, Dict[str, Any]] = {}
         self._derived_from_parameters: set[str] = set()
