@@ -22,7 +22,7 @@ warnings.formatwarning = warning_on_one_line  # type: ignore
 class StoichiometricMixin(CompoundMixin, BaseModel):
     """Mixin for stoichiometries."""
 
-    def __init__(self, rate_stoichiometries: dict = None) -> None:
+    def __init__(self, rate_stoichiometries: dict[str, dict[str, float]] | None = None) -> None:
         self.stoichiometries: Dict[str, Dict[str, float]] = {}
         self.stoichiometries_by_compounds: Dict[str, Dict[str, float]] = {}
         if rate_stoichiometries is not None:
