@@ -34,12 +34,12 @@ class LabelModel(Model):
 
     def __init__(
         self,
-        parameters: dict = None,
-        compounds: List[str] = None,
-        algebraic_modules: dict = None,
-        rate_stoichiometries: Dict[str, Dict[str, int]] = None,
-        rates: dict = None,
-        meta_info: dict = None,
+        parameters: dict[str, float] | None = None,
+        compounds: List[str] | None = None,
+        algebraic_modules: dict[str, dict[str, Any]] | None = None,
+        rate_stoichiometries: Dict[str, Dict[str, int]] | None = None,
+        rates: dict[str, dict[str, Any]] | None = None,
+        meta_info: dict | None = None,
     ):
         self.label_compounds: Dict[str, Dict[str, Any]] = {}
         self.nonlabel_compounds: List[str] = []
@@ -365,11 +365,11 @@ class LabelModel(Model):
         self,
         module_name: str,
         function: Callable,
-        compounds: List[str] = None,
-        derived_compounds: List[str] = None,
-        modifiers: List[str] = None,
-        parameters: List[str] = None,
-        args: List[str] = None,
+        compounds: List[str] | None = None,
+        derived_compounds: List[str] | None = None,
+        modifiers: List[str] | None = None,
+        parameters: List[str] | None = None,
+        args: List[str] | None = None,
     ):
         """Add an algebraic module to the model.
 
@@ -758,7 +758,7 @@ class LabelModel(Model):
     def generate_y0(
         self,
         base_y0: Union[ArrayLike, Dict[str, float]],
-        label_positions: Dict[str, Union[int, List[int]]] = None,
+        label_positions: Dict[str, Union[int, List[int]]] | None = None,
     ) -> Dict[str, float]:
         """Generate y0 for all isotopomers given a base y0.
 
